*   Title:  POINT CHARGE:
*           derivatives of retarded and advanced quantities
*    File:  derivs.frm
*   Tests:  derivs-test.frm
*  Author:  David N. Williams
* License:  Creative Commons Attribution-Share Alike
* Started:  July 12, 2012
* Revised:  July 12-16, 2012
*           August 27-31, 2012
*           September 1-3,5,8, 2012
*
* All parts of this program not in the public domain are:
*
*   Copyright (C) 1987-1990, 2012 David N. Williams
*
* This work is licensed under the Creative Commons Attribution-
* Share Alike 2.5 License.  To view a copy of this license, visit
* http://creativecommons.org/licenses/by-sa/2.5/ or send a letter
* to Creative Commons, 543 Howard Street, 5th Floor, San
* Francisco, California, 94105, USA.
*
*   Input:  none
*  Output:  derivs.sav

#if 0
This program computes the partial derivatives of the retarded or
advanced four-vectors r, u, a, and j described below, of their
explicit dot products, and of the scalar function f = f(r⋅u). 
These may be combined as tensor and scalar products in
expressions.

The output in derivs.sav is intended to be a comprehensive set
of monomials with partial derivatives through second order and
up to quadratic tensors in the vectors, with two exceptions:

1. Only one ordering for tensor products is provided.  For
   example, dru(mu,nu,la) is provided, but dur(mu,nu,la) is not,
   because it is equal to dru(mu,la,mu).

2. Partial derivatives that would produce second derivatives of
   the jerk, d²j/dτ², are omitted.

Derivatives of third order are included on an as needed basis.

All quantities are expressed in terms of the speed of light c
and the following four-vectors:

  x       Space-time field point, x ∈ ℝ⁴.
  y(τ)    Particle four-position at proper time τ.  The
          curve in ℝ⁴ is the "world line".
  u(τ)    Particle four-velocity dy/dτ.
  a(τ)    Particle four-acceleration du/dτ. 
  j(τ)    Particle four-jerk da/dτ.
  r       Light-cone displacement r = x - y[τ(x)], where τ(x)
          is either of the two solutions of r⋅r = 0.
  ∂       Four-vector gradient with respect to x.

Unless otherwise stated, it is always assumed that τ is
evaluated at the retarded or the advanced solution of r⋅r = 0
for τ(x).

Our Lorentz metric is (+---), but is never explicit, except in
the identification u⋅u = c².  It is implicit in the statement
that the retarded/advanced values of sgn(r⋅u) = sgn(r⁰) are ±1,
respectively.

All derivatives computed are valid for both retarded and
advanced evaluations of τ.

NOTATION

  f,f1,f2  Function f(r⋅u) and its first and second derivatives
           f'(r⋅u) and f"(r⋅u).
  d        Four-vector gradient ∂.		

Characteristic examples of the convention for the naming of
results are dfru(mu,nu,la) for ∂(fru), where ∂, r, and u have
indices mu, nu, and la respectively, and [d.fru](mu) for
∂⋅(fru), where the indices of ∂ and r are summed, and mu is the
index of u.  The notation for d is an operator notation in that
it acts on everything to the right.  Occasionally clarifying
parentheses are provided when dot products are involved, as in
[r.d(r.u)].

USAGE

Quantities that are to be differentiated by the differentiation
procedure must be written with square bracket names from one of
the FORM sets of cfunctions, cscal or cvec, declared below.
Possibly a future version of this program will include a
translator so that expressions without bracketed quantities can
be used.

As cfunctions, all dot products of bracketed vectors in the input
expression must have explicit repeated indices, to be recognized
for differentiation.  See the global expression for [r.d(r.u)]
below for an example.

The differentiator can be iterated on its unconverted output,
which consists of bracketed cfunctions.  Two conversion
procedures idvec is used to convert bracketed cfunctions in the
final result to unbracketed FORM vectors or symbols.  There is
also a procedure idmetric to account for the Lorentz metric. 
See the calculations below for examples of usage.

The differentiator does not work properly on powers of scalars,
like [f]^3 or [r.u^-1]^2.  Instead, they have to be flattened,
as in

  G [ddf^3(r.u)^-1)^2](mu,nu) = [f]*[f]*[f]*[r.u^-1]*[r.u^-1];
  #call partial(nu)
  #call partial(mu)
  #call idvec
  #call idmetric
#endif

*** DEBUGGING

#procedure try
print;
.store
save derivs.sav;
.end
#endprocedure

*** DECLARATIONS

#include derivs-ra.h

off statistics;
I mu,nu,la,ro;
.global

*** MODULES

G dr(la,nu) = [r](nu);
G du(la,nu) = [u](nu);
G da(la,nu) = [a](nu);
G dj(la,nu) = [j](nu);

#call partial(la)
#call idvec;
print;
.store

G [d(r.u)](la) = [r](mu)*[u](mu);
G [d(r.a)](la) = [r](mu)*[a](mu);

#call partial(la)
#call idvec
#call idmetric
print;
.store

G [d.r] = [r](mu);
G [d.u] = [u](mu);
G [d.a] = [a](mu);
G [d.j] = [j](mu);

#call partial(mu)
#call idvec
#call idmetric
print;
.store

G [r.dr](mu) = r(nu)*[r](mu); 
G [r.du](mu) = r(nu)*[u](mu); 
G [r.da](mu) = r(nu)*[a](mu); 
G [r.dj](mu) = r(nu)*[j](mu); 

G [u.dr](mu) = u(nu)*[r](mu); 
G [u.du](mu) = u(nu)*[u](mu); 
G [u.da](mu) = u(nu)*[a](mu); 

G [a.dr](mu) = a(nu)*[r](mu); 
G [a.du](mu) = a(nu)*[u](mu); 
G [a.da](mu) = a(nu)*[a](mu); 

#call partial(nu)
#call idvec
#call idmetric
print;
.store

G df(la)  = [f];
G df1(la) = [f1];
#call partial(la)
#call idvec
#call idmetric
print;
.store

G [r.d(r.u)] = r(mu)*[r](nu)*[u](nu);
G [r.d(r.a)] = r(mu)*[r](nu)*[a](nu);
G [u.d(r.u)] = u(mu)*[r](nu)*[u](nu);
G [u.d(r.a)] = u(mu)*[r](nu)*[a](nu);
G [a.d(r.u)] = a(mu)*[r](nu)*[u](nu);
G [a.d(r.a)] = a(mu)*[r](nu)*[a](nu);
#call partial(la)
multiply g(la,mu);
#call idvec
#call idmetric
print;
.store

G [r.df] = r(mu)*[f];
G [u.df] = u(mu)*[f];
#call partial(mu)
#call idvec
#call idmetric
print;
.store

G dfr(la,nu)  = [f]*[r](nu);
G dfu(la,nu)  = [f]*[u](nu);
G dfa(la,nu)  = [f]*[a](nu);
G dfj(la,nu)  = [f]*[j](nu);
G df1r(la,nu) = [f1]*[r](nu);
G df1u(la,nu) = [f1]*[u](nu);
G df1a(la,nu) = [f1]*[a](nu);
G df1j(la,nu) = [f1]*[j](nu);
#call partial(la)
#call idvec
#call idmetric
print;
.store

G drr(la,mu,nu) = [r](mu)*[r](nu);
G dru(la,mu,nu) = [r](mu)*[u](nu);
G dra(la,mu,nu) = [r](mu)*[a](nu);
G drj(la,mu,nu) = [r](mu)*[j](nu);
G duu(la,mu,nu) = [u](mu)*[u](nu);
G dua(la,mu,nu) = [u](mu)*[a](nu);
G duj(la,mu,nu) = [u](mu)*[j](nu);
G daa(la,mu,nu) = [a](mu)*[a](nu);
G daj(la,mu,nu) = [a](mu)*[j](nu);

G dfrr(la,mu,nu) = [f]*[r](mu)*[r](nu);
G dfru(la,mu,nu) = [f]*[r](mu)*[u](nu);
G dfra(la,mu,nu) = [f]*[r](mu)*[a](nu);
G dfrj(la,mu,nu) = [f]*[r](mu)*[j](nu);
G dfuu(la,mu,nu) = [f]*[u](mu)*[u](nu);
G dfua(la,mu,nu) = [f]*[u](mu)*[a](nu);
G dfuj(la,mu,nu) = [f]*[u](mu)*[j](nu);
G dfaa(la,mu,nu) = [f]*[a](mu)*[a](nu);
G dfaj(la,mu,nu) = [f]*[a](mu)*[j](nu);

#call partial(la)
#call idvec
#call idmetric
print;
.store

G [d.fr] = dfr(mu,mu);
G [d.fu] = dfu(mu,mu);
G [d.fa] = dfa(mu,mu);
G [d.fj] = dfj(mu,mu);
print;
.store

G [d.frr](mu) = dfrr(nu,nu,mu); 
G [d.fru](mu) = dfru(nu,nu,mu); 
G [d.fra](mu) = dfra(nu,nu,mu); 
G [d.fur](mu) = dfru(nu,mu,nu); 
G [d.fuu](mu) = dfuu(nu,nu,mu); 
G [d.fua](mu) = dfua(nu,nu,mu); 
G [d.far](mu) = dfra(nu,mu,nu); 
G [d.fau](mu) = dfua(nu,mu,nu); 
G [d.faa](mu) = dfaa(nu,nu,mu); 
#call idmetric
print;
.store

G ddf(mu,nu) = [f];

G ddr(mu,nu,la) = [r](la);
G ddu(mu,nu,la) = [u](la);
G dda(mu,nu,la) = [a](la);

G ddfr(mu,nu,la) = [f]*[r](la);
G ddfu(mu,nu,la) = [f]*[u](la);
G ddfa(mu,nu,la) = [f]*[a](la);

G ddrr(mu,nu,la,ro) = [r](la)*[r](ro);
G ddru(mu,nu,la,ro) = [r](la)*[u](ro);
G ddra(mu,nu,la,ro) = [r](la)*[a](ro);
G dduu(mu,nu,la,ro) = [u](la)*[u](ro);
G ddua(mu,nu,la,ro) = [u](la)*[a](ro);
G ddaa(mu,nu,la,ro) = [a](la)*[a](ro);

G ddfrr(mu,nu,la,ro) = [f]*[r](la)*[r](ro);
G ddfru(mu,nu,la,ro) = [f]*[r](la)*[u](ro);
G ddfra(mu,nu,la,ro) = [f]*[r](la)*[a](ro);
G ddfuu(mu,nu,la,ro) = [f]*[u](la)*[u](ro);
G ddfua(mu,nu,la,ro) = [f]*[u](la)*[a](ro);
G ddfaa(mu,nu,la,ro) = [f]*[a](la)*[a](ro);

#call partial(nu)
#call partial(mu)
#call idvec
#call idmetric
print;
.store

*** AD HOC UNTESTED MODULES

G dddfr(mu,nu,la,ro) = [f]*[r](ro);
#call partial(la)
#call partial(nu)
#call partial(mu)
#call idvec
#call idmetric
print +s;
.store

save derivs.sav;
.end
