*   Title:  POINT CHARGE:
*           tests for energy-momentum tensor as a tempered distribution
*    File:  energy-tensor-test.frm
*  Author:  David N. Williams
* License:  Creative Commons Attribution-Share Alike
* Started:  September 3, 2012
* Revised:  September 3-5,7,10,11, 2012
*
* All parts of this program not in the public domain are:
*
*   Copyright (C) 1987-1990, 2012 David N. Williams
*
* This work is licensed under the Creative Commons Attribution-
* Share Alike 2.5 License.  To view a copy of this license, visit
* http://creativecommons.org/licenses/by-sa/2.5/ or send a letter
* to Creative Commons, 543 Howard Street, 5th Floor, San
* Francisco, California, 94105, USA.
*
*   Input:  energy-tensor.sav
*  Output:  log file

#if 0
The calculation in energy-tensor.frm realizes the retarded or
advanced energy-momentum tensor for the electromagnetic field of
a point charge as a tempered distribution.  This program
verifies agreement with our hand calculated Master Sheet dated
October 13, 1974.
#endif

*** DECLARATIONS

#include derivs-ra.h

off statistics;
I mu,nu,la,ro;
* tensors for pretty printing
CF [r,u],[r,a],[rr],[{r,u}],[{r,a}],[uu],[{u,a}],[aa];

Load energy-tensor.sav;

*** MODULES

L diff1 = - t1(mu,nu)
  + g(mu,nu)*c^2*( 2*r.a - c^2 )/r.u^4
;

L diff2 = - t2(mu,nu)
  + g(mu,nu)*(-c^2)*2*( r.a - c^2 )/r.u^4
#if 0
  + u(mu)*u(nu)*6*c^2/r.u^4
  + r(mu)*r(nu)*( 8*c^2*( r.a - c^2 )^2/r.u^6 - 2*c^2*r.j/r.u^5 ) 
  + ( r(mu)*u(nu) + u(mu)*r(nu) )*8*c^2*( r.a - c^2 )/r.u^5
  + ( r(mu)*a(nu) + a(mu)*r(nu) )*(-2*c^2)/r.u^4
#else
  + [uu](mu,nu)*6*c^2/r.u^4
  + [rr](mu,nu)*( 8*c^2*( r.a - c^2 )^2/r.u^6 - 2*c^2*r.j/r.u^5 ) 
  + [{r,u}](mu,nu)*8*c^2*( r.a - c^2 )/r.u^5
  + [{r,a}](mu,nu)*(-2*c^2)/r.u^4
#endif
;

L diff3 = - t3(mu,nu)
  + g(mu,nu)*3/2*c^4/r.u^4
#if 0
  + r(mu)*r(nu)*3*c^4*( 2*r.a + c^2 )/r.u^6 
  + ( r(mu)*u(nu) + u(mu)*r(nu) )*(-3*c^4)/r.u^5
#else
  + [rr](mu,nu)*3*c^4*( 2*r.a + c^2 )/r.u^6 
  + [{r,u}](mu,nu)*(-3*c^4)/r.u^5
#endif
;

L diff4 = -t4(mu,nu)
#if 0
  + u(mu)*u(nu)*3*c^2/r.u^4
  + ( r(mu)*u(nu) + u(mu)*r(nu) )*(-9/2)*c^2*r.a/u.r^5
  + ( r(mu)*a(nu) + a(mu)*r(nu) )*3/2*c^2/r.u^4
#else
  + [uu](mu,nu)*3*c^2/r.u^4
  + [{r,u}](mu,nu)*(-9/2)*c^2*r.a/u.r^5
  + [{r,a}](mu,nu)*3/2*c^2/r.u^4
#endif
;

L diff5 = -t5(mu,nu)
  + g(mu,nu)*(-3*c^4)/r.u^4
#if 0
  + u(mu)*u(nu)*(-9*c^2)/r.u^4
  + r(mu)*r(nu)*12*c^4*( r.a - c^2 )/r.u^6
  + ( r(mu)*u(nu) + u(mu)*r(nu) )*c^2*( -9/2*r.a + 12*c^2 )/r.u^5
  + ( r(mu)*a(nu) + a(mu)*r(nu) )*3/2*c^2/r.u^4
#else
  + [uu](mu,nu)*(-9*c^2)/r.u^4
  + [rr](mu,nu)*12*c^4*( r.a - c^2 )/r.u^6
  + [{r,u}](mu,nu)*c^2*( -9/2*r.a + 12*c^2 )/r.u^5
  + [{r,a}](mu,nu)*3/2*c^2/r.u^4
#endif
;

* CEM, p. 8
G diffT1 = -TCEM(mu,nu)
  - 1/2*g(mu,nu)*c^4/r.u^4
#if 0
  + r(mu)*r(nu)*( -a.a - c^2*( c^2 - r.a )^2/r.u^2 )/r.u^4 
  + ( r(mu)*u(nu) + u(mu)*r(nu) )*c^2*( c^2 - r.a )/r.u^5
  + ( r(mu)*a(nu) + a(mu)*r(nu) )*c^2/r.u^4
#else
  + [rr](mu,nu)*( -a.a - c^2*( c^2 - r.a )^2/r.u^2 )/r.u^4 
  + [{r,u}](mu,nu)*c^2*( c^2 - r.a )/r.u^5
  + [{r,a}](mu,nu)*c^2/r.u^4
#endif
;

* This verifies the distributional energy-momentum tensor.
L diffT2 = -TCEM(mu,nu)
  + t1(mu,nu) + t2(mu,nu) + t3(mu,nu) + t4(mu,nu)
  + t5(mu,nu) + t6(mu,nu)
;

L diff7 = -t7(mu,nu) - 2*t1(mu,nu) + t2(mu,nu);
L diffT3 =  -TCEM(mu,nu) + T(mu,nu);

print +s;
.end
