*   Title:  POINT CHARGE:
*           energy-momentum tensor as a tempered distribution
*    File:  energy-tensor.frm
*   Tests:  energy-tensor-test.frm
*  Author:  David N. Williams
* License:  Creative Commons Attribution-Share Alike
* Started:  August 28, 2012
* Revised:  August 28, 2012
*           September 3-5,7-11,28, 2012
*           October 9,14, 2012
*
* All parts of this program not in the public domain are:
*
*   Copyright (C) 1987-1990, 2012 David N. Williams
*
* This work is licensed under the Creative Commons Attribution-
* Share Alike 2.5 License.  To view a copy of this license, visit
* http://creativecommons.org/licenses/by-sa/2.5/ or send a letter
* to Creative Commons, 543 Howard Street, 5th Floor, San
* Francisco, California, 94105, USA.
*
*   Input:  derivs.sav, derivs-ra.h
*  Output:  energy-momentum.sav

#if 0
This program verifies the derivatives portion of a computation
we finished before October 13, 1974, which showed how to realize
the energy-momentum tensor for the retarded or advanced
(ret/adv) electromagnetic field of a point charge as a tempered
distribution.  We delayed publication, and ended up being
scooped by the independent work of E. G. Peter Rowe, Phys. Rev.
D18, 3639-54 (1978).  So we never submitted our result.

Many of the precalculated derivative expressions in derivs.sav
are not used.

We use Gaussian units.  The source point and all vectors and
tensors are retarded or advanced.  The Lorentz metric is (+---).
Indices have the values 0,1,2,3.

The source point and all vectors and tensors in the following
are retarded or advanced.

NOTATION
  c		 speed of light
  A		 Lorentz gauge four-vector Liénard-Wiechert potential
  F		 electromagnetic field tensor
  r		 light-cone four-displacement, from source to field point
  u		 four-velocity
  a		 four-acceleration
  j		 four-jerk
  s		 sgn(r⋅u) = sgn(r⁰)
  q		 charge
  f		 function of r⋅u
  ~t	 transpose of a second-rank tensor t

Bracketed quantities [r], [u], [a], [f], etc., are used on the
right-hand side of expressions that are to be differentiated by
the "partial" procedure in derivs-ra.h.

See derivs.frm for precalculated derivatives, such as ddf(mu,nu).

All derivatives are understood to be valid when r and r⋅u are
nonzero, i.e., off the world line.  Note that s = ±1 for
ret/adv fields.  A factor qs is left out of A and its
derivative.  Since it propagates through the derivative of A,
occurrences of the field tensor F should be multiplied by it.
That is, energy-momentum tensor results should be multiplied by
(qs)² = q².
#endif

*** DECLARATIONS

#include derivs-ra.h

off statistics;
I mu,nu,la,ro;
* tensors for pretty printing
CF [r,u],[r,a],[rr],[{r,u}],[{r,a}],[uu],[{u,a}],[aa];

Load derivs.sav;
.global

*** PROCEDURES

* debugging
#procedure try
print +s;
.end
#endprocedure

* NOTE:  no dummies in these two procedures
#procedure idantisym
  Id r(mu)*u(nu) = [r,u](mu,nu) + r(nu)*u(mu);
  Id r(mu)*a(nu) = [r,a](mu,nu) + r(nu)*a(mu);
  Id u(mu)*a(nu) = [u,a](mu,nu) + u(nu)*a(mu);
#endprocedure
*
#procedure idsym
  Id r(mu)*r(nu) = [rr](mu,nu);
  Id r(mu)*u(nu) = [{r,u}](mu,nu) - r(nu)*u(mu);
  Id r(mu)*a(nu) = [{r,a}](mu,nu) - r(nu)*a(mu);
  Id u(mu)*u(nu) = [uu](mu,nu);
  Id a(mu)*a(nu) = [aa](mu,nu);
#endprocedure


*** MASTER SHEET

*
* The tensors in this section are from the the 1974 master
* sheet.  Unfortunately it uses notation like (A⋅A)² for
* c⁴/(r⋅u)⁴, which is misleading, because the energy-momentum
* tensor is actually quadratic in A.  We keep that notation in
* the commented formulas to facilitate comparison with the
* master sheet.
*

* A = u/(r⋅u) (omits qs)
G A(mu) = f*u(mu);
#call idf
#call idmetric
print +s;
.store

* F = ∂A - ~∂A
G F(mu,nu) = dfu(mu,nu) - dfu(nu,mu);
#call idf
#call idmetric
*#call idantisym
*B [r,u],[r,a];
print +s;
.store

* t₁ = 1/2 ∂⋅∂(A⋅A) g = 1/2 c²∂⋅∂[1/(r⋅u)²)] g
G t1(mu,nu) = 1/2*c^2*ddf(la,la)*g(mu,nu);
#call idfp2
#call idmetric
#call idsym
B g,[rr],[{r,u}],[{r,a}];
print +s;
.store

* t₂ = ∂∂(A⋅A) = c²∂∂[1/(r⋅u)²)]
G t2(mu,nu) = c^2*ddf(mu,nu);
#call idfp2
#call idmetric
#call idsym
B g,[rr],[{r,u}],[{r,a}];
print +s;
.store

* t₃ =3/4 ∂⋅∂[(A⋅A)²rr] = 3/4 c⁴∂⋅∂[rr/(r⋅u)⁴]
G t3(mu,nu) = 3/4*c^4*ddfrr(la,la,mu,nu);
#call idfp4
#call idmetric
#call idsym
B g,[rr],[{r,u}],[{r,a}];
print +s;
.store

* t₄ = -3/4 ∂⋅∂[A⋅A(rA + Ar)] = -3/4 c²∂⋅∂[(ru + ur)/(r⋅u)³] 
G t4(mu,nu) = - 3/4*c^2*( ddfru(la,la,mu,nu) + ddfru(la,la,nu,mu) );
#call idfp3
#call idmetric
#call idsym
B g,[rr],[{r,u}],[{r,a}];
print +s;
.store

* t₅ = -3/4 ∂⋅∂[∂(A⋅Ar) + ~∂(A⋅Ar)]
*    = -3/4 c²∂⋅∂{∂[r/(r⋅u)²] + ~∂[r/(r⋅u)²]}
G t5(mu,nu) = -3/4*c^2*( dddfr(la,la,mu,nu) + dddfr(la,la,nu,mu) );
#call idfp2
#call idmetric
#call idsym
B g,[rr],[{r,u}],[{r,a}];
print +s;
.store

* w₅ = -3/4 [∂(A⋅Ar) + ~∂(A⋅Ar)]
*    = -3/4 c²{∂[r/(r⋅u)²] + ~∂[r/(r⋅u)²]}
* ∂⋅∂ w₅ = t₅
G w5(mu,nu) = -3/4*c^2*( dfr(mu,nu) + dfr(nu,mu) );
#call idfp2
#call idmetric
#call idsym
B g,[rr],[{r,u}],[{r,a}];
print +s;
.store

* This does not vanish.
G [d.w5](mu) = -3/4*c^2*( ddfr(nu,nu,mu) + ddfr(nu,mu,nu) );
#call idfp2
#call idmetric
print +s;
.store

* t₆ = rr[-a⋅a - 9c²(r⋅a)²/(r⋅u)² + 2c²r⋅j/r⋅u]/(r⋅u)⁴
G t6(mu,nu) = r(mu)*r(nu)*
  ( -a.a - 9*c^2*r.a^2/r.u^2 + 2*c^2*r.j/r.u )/r.u^4;
#call idsym
B g,[rr],[{r,u}],[{r,a}];
print +s;
.store

* Maxwell energy-momentum tensor, absent a factor 1/4π.
* The extra substitution for FF is a temporary workaround for a
* bug in FORM, suggested by Jos Vermaseren.
CF FF;
G TCEM(mu,nu) = FF(mu,la)*FF(la,nu) + 1/4*g(mu,nu)*FF(la,ro)*FF(la,ro);
Id FF(mu?,nu?) = F(mu,nu);
#call idmetric
#call idsym
print +s;
.store


*** REARRANGEMENT

*
* The tensors in this section are from the master sheet
* supplementary page.  They rearrange the energy-momentum tensor
* into a sum of terms with vanishing four-divergence off the
* world line, which are used in our hand calculation of the
* divergence on the world line.  The Tensor wi, wii,and wiii are
* factors whose divergences vanish before a d'Alembertian is
* applied.
*

* wi = -9/4 rr (A⋅A)²        ti = ⃞ wi
G [d.wi](mu) = -9/4*c^4*dfrr(nu,nu,mu);
#call idfp4
#call idmetric
print +s;
.store

* wii = 3/2 rA (A⋅A)        tii =  ⃞ wiii
G [d.wii](mu) = 3/2*c^4*dfru(nu,nu,mu);
#call idfp3
#call idmetric
print +s;
.store

* waiii = 3/2 Ar (A⋅A)       taiii =  ⃞ waiii 
G [d.waiii](mu) = 3/2*c^2*dfru(nu,mu,nu);
#call idfp3
#call idmetric
print +s;
.store

* wbiii = 3 rr (A⋅A)² r⋅a/c²   tbiii =  ⃞ wbiii
G [d.wbiii](mu) = 3*[r](nu)*[r](mu)*[f]*[r](la)*[a](la)*c^2;
#call partial(nu)
#call idvec
#call idmetric
#call idfp4
print +s;
.store

* wiii = waiii + wbiii      tiii =  ⃞ wiii
G [d.wiii](mu) = [d.waiii](mu) + [d.wbiii](mu);
print;
.store

* Note that all three pieces of t6 = t6a + t6b + t6c have
* vanishing divergence off the world line.

* t6a = -rr a⋅a/(r⋅u)⁴
G [d.t6a](mu) = -[r](nu)*[r](mu)*[f]*[a](la)*[a](la);
#call partial(nu)
#call idvec
#call idmetric
#call idfp4
print;
.store

* t6b =  -9 rr c²(r⋅a)²/(r⋅u)⁶
G [d.t6b](mu)= -9*[r](nu)*[r](mu)*[f]*c^2*[r](la)*[a](la)*[r](ro)*[a](ro);
#call partial(nu)
#call idvec
#call idmetric
#call idfp6
print;
.store

* t6c =   2 rr c² r⋅j/r⋅u⁵ 
G [d.t6c](mu) = 2*[r](nu)*[r](mu)*[f]*c^2*[r](la)*[j](la);
#call partial(nu)
#call idvec
#call idmetric
#call idfp5
print;
.store

* t₇ = -g ⃞(A⋅A) + ∂∂(A⋅A) = (-g ⃞ + ∂∂) c²/(r⋅u)² 
* ∂⋅t₇ = 0 by inspection of the above line
G t7(mu,nu) = - g(mu,nu)*ddfuu(la,la,ro,ro) + ddfuu(mu,nu,la,la);
#call idfp2
#call idmetric
#call idsym
B g,[rr],[{r,u}],[{r,a}];
print +s;
.store

* tᵢ = -9/4 ⃞ [rr c⁴/(r⋅u)⁴] 
G ti(mu,nu) = -9/4*[r](mu)*[r](nu)*[f]*c^4;
#call partial(la)
#call partial(la)
#call idvec
#call idmetric
#call idfp4
print +s;
.store

* tᵢᵢ = 3/2 ⃞ [ru c²/(r⋅u)³]
G tii(mu,nu) = 3/2*[r](mu)*[u](nu)*[f]*c^2;
#call partial(la)
#call partial(la)
#call idvec
#call idmetric
#call idfp3
print +s;
.store

* taᵢᵢᵢ = 3/2 ⃞ [ur c²/(r⋅u)³]
G taiii(mu,nu) = 3/2*[u](mu)*[r](nu)*[f]*c^2;
#call partial(la)
#call partial(la)
#call idvec
#call idmetric
#call idfp3
print +s;
.store

* tbᵢᵢᵢ = 3 ⃞ [rr c² r⋅a/(r⋅u)⁴]
G tbiii(mu,nu) = 3*[r](mu)*[r](nu)*c^2*[f]*[r](ro)*[a](ro);
#call partial(la)
#call partial(la)
#call idvec
#call idmetric
#call idfp4
print +s;
.store

G T(mu,nu) = t7(mu,nu) + ti(mu,nu)  + tii(mu,nu)
   + taiii(mu,nu)  + tbiii(mu,nu)  + t6(mu,nu) 
;
#call idsym
B g,[rr],[{r,u}],[{r,a}];
print +s;
.store

save energy-tensor.sav;
.end
